@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -27,6 +27,7 @@ import wb_source_control_providers
 import wb_platform_specific
 import wb_bookmarks_dialogs
 import wb_toolbars
+import wb_subversion_utils
 
 import wb_config
 
@@ -118,6 +119,9 @@ class WbFrame(wx.Frame):
         self.menu_actions.Append( wb_ids.id_SP_Revert, T_('Revert...'), T_('Revert') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Cleanup, T_('Clean up'), T_('Clean up working copy') )
+        if wb_subversion_utils.version_info.has_upgrade:
+            self.menu_actions.AppendSeparator()
+            self.menu_actions.Append( wb_ids.id_SP_Upgrade, T_('Upgrade'), T_('Upgrade working copy') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_CreateTag, T_('Create Tag...'), T_('Create Tag') )
         self.menu_actions.Append( wb_ids.id_SP_CreateBranch, T_('Create Branch...'), T_('Create Branch') )
@@ -345,6 +349,10 @@ class WbFrame(wx.Frame):
         wx.EVT_MENU( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnSpUpdateTo ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnUpdateUiSpUpdateTo ) )
 
+        if wb_subversion_utils.version_info.has_upgrade:
+            wx.EVT_MENU( self, wb_ids.id_SP_Upgrade, self.app.eventWrapper( self.OnSpUpgrade ) )
+            wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Upgrade, self.app.eventWrapper( self.OnUpdateUiSpUpgrade ) )
+
         wx.EVT_MENU( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnSpReportUpdates ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnUpdateUiSpReportUpdates ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Report_LocksWc, self.app.eventWrapper( self.OnSpReportLocksWc ) )
@@ -462,13 +470,17 @@ class WbFrame(wx.Frame):
         ver_str = ('%d.%d.%d-%d\n' %
                     (wb_version.major, wb_version.minor,
                      wb_version.patch, wb_version.build))
-        str_message =    ((T_('Work Bench version: %s') % ver_str) +
-                '\n' + wb_source_control_providers.getProviderAboutStrings() +
-                '\nwxPython %d.%d.%d.%d %s' % wx.VERSION +
-                '\nPython %d.%d.%d %s %d\n' % sys.version_info +
-                T_('\nCopyright Barry Scott (c) 2003-2009. All rights reserved')
-                )
-        wx.LogMessage( str_message )
+        str_message_parts = [T_('Work Bench version: %s') % ver_str
+                            ,wb_source_control_providers.getProviderAboutStrings()
+                            ,'wxPython %d.%d.%d.%d %s' % wx.VERSION
+                            ,'Python %d.%d.%d %s %d\n' % (sys.version_info[0]
+                                                         ,sys.version_info[1]
+                                                         ,sys.version_info[2]
+                                                         ,sys.version_info[3]
+                                                         ,sys.version_info[4])
+
+                            ,T_('\nCopyright Barry Scott (c) 2003-2011. All rights reserved')]
+        wx.LogMessage( '\n'.join( str_message_parts ) )
 
     def OnCmdPreferences( self, event ):
         pref_dialog = wb_preferences_dialog.PreferencesDialog( self, self.app )
@@ -770,7 +782,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpAnnotate( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.versioned and (not self.ui_state_focus.is_folder) )
@@ -780,7 +793,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpCheckin( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.need_checkin
@@ -872,7 +886,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpDiffWorkHead( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             if self.ui_state_list is self.ui_state_focus:
@@ -888,14 +903,16 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpDiffWorkBranchOriginBase( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_list.versioned and not self.ui_state_list.new_versioned )
 
     def OnUpdateUiSpDiffWorkBranchOriginHead( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_list.versioned and not self.ui_state_list.new_versioned )
@@ -907,7 +924,8 @@ class WbFrame(wx.Frame):
         self.getUpdateUiState()
         if wb_config.debug_selection_update: print 'ZF: OnUpdateUiSpHistory versioned %r handler %r' % (
                                                 self.ui_state_focus.versioned, self.event_handler)
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.versioned and not self.ui_state_focus.new_versioned )
@@ -917,7 +935,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpInfo( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.versioned )
@@ -949,7 +968,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpProperties( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.versioned )
@@ -1001,7 +1021,8 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpRevert( self, event ):
         self.getUpdateUiState()
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
         else:
             event.Enable( self.ui_state_focus.revertable )
@@ -1019,7 +1040,8 @@ class WbFrame(wx.Frame):
     def OnUpdateUiSpUpdate( self, event ):
         self.getUpdateUiState()
 
-        if self.ui_state_focus.need_checkout:
+        if( self.ui_state_focus.need_checkout
+        or self.ui_state_focus.need_upgrade ):
             event.Enable( False )
 
         elif self.ui_state_focus.is_project_parent:
@@ -1041,6 +1063,16 @@ class WbFrame(wx.Frame):
     def OnUpdateUiSpUpdateTo( self, event ):
         self.OnUpdateUiSpUpdate(event)
 
+    def OnSpUpgrade( self, event ):
+        self.clearUpdateUiState()
+        return self.tree_panel.OnSpUpgrade()
+
+    def OnUpdateUiSpUpgrade( self, event ):
+        self.getUpdateUiState()
+
+        # this is a tree only command
+        event.Enable( self.list_panel.list_handler.project_info.need_upgrade )
+
     #----------------------------------------
     def Sp_Dispatch( self, sp_func_name ):
         self.clearUpdateUiState()
@@ -1102,7 +1134,7 @@ class LogCtrlPanel(wx.Panel):
         self.text_ctrl = StyledLogCtrl( self.app, self )
 
         # Redirect the console IO to this panel
-        sys.stdin = file( wb_platform_specific.getNullDevice(), 'r' )
+        sys.stdin = wb_platform_specific.uOpen( wb_platform_specific.getNullDevice(), 'r' )
         if self.app.isStdIoRedirect():
             sys.stdout = self
             sys.stderr = self
