@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -35,6 +35,7 @@ class TreeState:
         self.unversioned = False
         self.need_checkin = False
         self.need_checkout = False
+        self.need_upgrade = False
         self.conflict = False
         self.file_exists = False
         self.is_folder = True
@@ -127,13 +128,11 @@ class WbTreePanel(wx.Panel):
         dc.Clear()
         w, h = self.GetSize()
         if self.FindFocus() == self.tree_ctrl:
-            print 'tree focus'
             dc.SetPen( wx.Pen( "red", 1 ) )
             dc.DrawRectangle( 0, 0, w, h )
         else:
             dc.SetPen( wx.Pen( "green", 1 ) )
             dc.DrawRectangle( 0, 0, w, h )
-            print 'tree unfocus'
         event.Skip()
 
     def initFrame( self ):
@@ -266,6 +265,7 @@ class WbTreePanel(wx.Panel):
 
         if first_item:
             self.tree_ctrl.SelectItem( first_item )
+            # QQQ: EnsureVisible causes an assert in wxPython 2.8.12.1 on Mac OS X
             self.tree_ctrl.EnsureVisible( first_item )
 
     def updateTreeSelectedItem( self ):
@@ -318,12 +318,14 @@ class WbTreePanel(wx.Panel):
         child_item, cookie = self.tree_ctrl.GetFirstChild( this_item )
         while child_item:
             child_handler = self.tree_ctrl.GetPyData( child_item )
+            # Since WX 2.8.11.1 need to call updateStatus() here - guess that a callback sequence changed
+            child_handler.updateStatus()
             self.tree_ctrl.SetItemHasChildren( child_item, child_handler.mayExpand() )
             self.tree_ctrl.SetItemTextColour( child_item, child_handler.getTreeNodeColour() )
 
             child_item, cookie = self.tree_ctrl.GetNextChild( this_item, cookie )
 
-        # set the has children state
+        # set the has-children state
         self.tree_ctrl.SetItemHasChildren( this_item, len(project_info_list) > 0 )
 
     def gotoBookmark( self, bookmark_name ):
@@ -768,6 +770,9 @@ class WbTreePanel(wx.Panel):
     def OnSpUpdateTo( self ):
         return self.Sp_Dispatch( 'Cmd_Dir_UpdateTo' )
 
+    def OnSpUpgrade( self ):
+        return self.Sp_Dispatch( 'Cmd_Dir_Upgrade' )
+
     #----------------------------------------
     def OnSpCopy( self, filename_list ):
         return self.Sp_DispatchDrop( 'Cmd_Dir_Copy', filename_list )
